pub enum CriticalOptions {
None,
Custom(HashMap<String, String>),
}Expand description
Type that encapsulates the normal usage of the critical options field. I used a structure instead of an Option for consistency and possible future expansion into a ForceCommand type.
Variants
None
Don’t use any critical options
Custom(HashMap<String, String>)
Allows a custom set of critical options. Does not contain any standard options.