Extensions

Enum Extensions 

pub enum Extensions {
    Standard,
    Custom(HashMap<String, String>),
}
Type that encapsulates the normal usage of the extensions field.

Variants



Standard

Contains the five standard extensions: agent-forwarding, port-forwarding, pty, user-rc, X11-forwarding



Custom(HashMap<String, String>)

Allows a completely custom set of extensions to be passed in. This does not contain the standard extensions